# History

## 0.3.9 (2021-06-07)
    - Query: Minor fix in topics query. 

## 0.3.8 (2021-06-06)
    - Query: Modified order of displays in queries to improve usage on smartphones.

## 0.3.6 (2021-05-30)

    -Query: Changed "articles" query to select articles with at least 1 author that matches all restrictions. 

## 0.3.4 (2021-05-12)

- Patch: Load Jinja2 template and add Jinja2 as requirement
## 0.3.0 (2021-05-11)

-  Change code to use jinja2 templating for rendering html (contribution by @jvfe).

## 0.2.0 (2021-05-07)

-   Set up "advanced" mode, with yaml template for restricting the query.

## 0.1.0 (2021-04-19)

-   First release on PyPI.
